#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   gi-gtk-layer-shell
version:                0.1.7
visibility:             public
id:                     gi-gtk-layer-shell-0.1.7-JnIontI6eBO2qTD7WT6lYB
key:                    gi-gtk-layer-shell-0.1.7-JnIontI6eBO2qTD7WT6lYB
license:                LGPL-2.1-only
maintainer:             Iñaki García Etxebarria
author:                 Iñaki García Etxebarria
homepage:               https://github.com/haskell-gi/haskell-gi
synopsis:               gtk-layer-shell bindings
description:            Bindings for gtk-layer-shell, autogenerated by haskell-gi.
category:               Bindings
abi:                    dd1bac7d9fdff04caaf51c83d1e083c0
exposed:                True
exposed-modules:
    GI.GtkLayerShell GI.GtkLayerShell.Config GI.GtkLayerShell.Enums
    GI.GtkLayerShell.Functions

import-dirs:            /usr/lib/ghc-9.6.6/site-local/gi-gtk-layer-shell-0.1.7
library-dirs:
    /usr/lib/ghc-9.6.6/site-local/gi-gtk-layer-shell-0.1.7 /usr/lib

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/gi-gtk-layer-shell-0.1.7 /usr/lib

dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/haskell-gi-gtk-layer-shell
hs-libraries:           HSgi-gtk-layer-shell-0.1.7-JnIontI6eBO2qTD7WT6lYB
extra-libraries:        gtk-layer-shell
extra-libraries-static:
    gtk-layer-shell gtk-3 gdk-3 pangocairo-1.0 m Xrandr Xcursor
    Xcomposite Xdamage Xinerama cloudproviders cairo-gobject dl
    gdk_pixbuf-2.0 m glycin-2 seccomp lcms2 m pthread atk-bridge-2.0
    atspi Xtst Xi Xfixes atk-1.0 dbus-1 xkbcommon wayland-cursor
    wayland-egl epoxy dl GL EGL pangoft2-1.0 m pango-1.0 m fribidi thai
    datrie Xft cairo m dl fontconfig m expat m Xext Xrender X11 pthread
    xcb-render xcb-shm xcb Xau Xdmcp pixman-1 m harfbuzz-gobject
    harfbuzz m freetype dl bz2 png16 m m brotlidec brotlicommon
    graphite2 gio-2.0 gobject-2.0 gmodule-2.0 glib-2.0 atomic m pcre2-8
    pthread z mount blkid systemd sysprof-capture-4 wayland-client m rt
    ffi

include-dirs:
    /usr/include/gtk-layer-shell /usr/include/gtk-3.0
    /usr/include/pango-1.0 /usr/include /usr/include/cloudproviders
    /usr/include/cairo /usr/include/gdk-pixbuf-2.0
    /usr/include/glycin-2 /usr/include/at-spi2-atk/2.0
    /usr/include/at-spi-2.0 /usr/include/atk-1.0 /usr/include/dbus-1.0
    /usr/lib/dbus-1.0/include /usr/include/fribidi
    /usr/include/pixman-1 /usr/include/harfbuzz /usr/include/freetype2
    /usr/include/libpng16 /usr/include/gio-unix-2.0
    /usr/include/glib-2.0 /usr/lib/glib-2.0/include
    /usr/include/libmount /usr/include/blkid /usr/include/sysprof-6

depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    gi-gdk3-3.0.30-JEUIMKq5S8h6d17kXJd7mC
    gi-gtk3-3.0.44-9SuLvOHt8JWLnndPnWN4Ez
    haskell-gi-0.26.17-CIEzbUsdQkiWVDD6PFVQU
    haskell-gi-base-0.26.9-A51M6LjdiVN4RjdHJdLeji
    haskell-gi-overloading-1.0-6w3IXGDooXgu3RA2LfTuf text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-gi-gtk-layer-shell/html/gi-gtk-layer-shell.haddock

haddock-html:           /usr/share/doc/haskell-gi-gtk-layer-shell/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

